@@ -25,6 +25,7 @@ from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.compute import metadata_utils
 from googlecloudsdk.api_lib.compute import utils
 from googlecloudsdk.api_lib.container import api_adapter
+from googlecloudsdk.api_lib.container import constants as api_constants
 from googlecloudsdk.api_lib.container import kubeconfig as kconfig
 from googlecloudsdk.api_lib.container import util
 from googlecloudsdk.api_lib.functions import api_enablement
@@ -241,6 +242,11 @@ def ParseCreateOptionsBase(
       addons = {api_adapter.RAYOPERATOR: True}
     else:
       addons[api_adapter.RAYOPERATOR] = True
+  if getattr(args, 'enable_slurm_operator', None):
+    if addons is None:
+      addons = {api_adapter.SLURMOPERATOR: True}
+    else:
+      addons[api_adapter.SLURMOPERATOR] = True
   if getattr(args, 'enable_lustre_csi_driver', None):
     if addons is None:
       addons = {api_adapter.LUSTRECSIDRIVER: True}
@@ -318,6 +324,7 @@ def ParseCreateOptionsBase(
       ),
       enable_legacy_authorization=get_default('enable_legacy_authorization'),
       enable_managed_prometheus=get_default('enable_managed_prometheus'),
+      enable_managed_mldiagnostics=get_default('enable_managed_mldiagnostics'),
       auto_monitoring_scope=get_default('auto_monitoring_scope'),
       enable_master_authorized_networks=get_default(
           'enable_master_authorized_networks'
@@ -339,6 +346,12 @@ def ParseCreateOptionsBase(
       labels=get_default('labels'),
       local_nvme_ssd_block=(local_nvme_ssd_block),
       local_ssd_count=get_default('local_ssd_count'),
+      maintenance_minor_version_disruption_interval=get_default(
+          'maintenance_minor_version_disruption_interval'
+      ),
+      maintenance_patch_version_disruption_interval=get_default(
+          'maintenance_patch_version_disruption_interval'
+      ),
       maintenance_window=get_default('maintenance_window'),
       maintenance_window_start=get_default('maintenance_window_start'),
       maintenance_window_end=get_default('maintenance_window_end'),
@@ -504,6 +517,7 @@ def ParseCreateOptionsBase(
           'enable_runtime_vulnerability_insight'
       ),
       workload_policies=get_default('workload_policies'),
+      autopilot_cluster_policies=get_default('autopilot_cluster_policies'),
       in_transit_encryption=get_default('in_transit_encryption'),
       enable_kernel_module_signature_enforcement=get_default(
           'enable_kernel_module_signature_enforcement'
@@ -573,6 +587,8 @@ def ParseCreateOptionsBase(
       enable_auto_ipam=get_default('enable_auto_ipam'),
       enable_k8s_tokens_via_dns=get_default('enable_k8s_tokens_via_dns'),
       enable_legacy_lustre_port=get_default('enable_legacy_lustre_port'),
+      disable_multi_nic_lustre=get_default('disable_multi_nic_lustre'),
+      enable_lustre_multi_nic=get_default('enable_lustre_multi_nic'),
       enable_pod_snapshots=enable_pod_snapshots,
       enable_default_compute_class=get_default('enable_default_compute_class'),
       enable_k8s_certs_via_dns=get_default('enable_k8s_certs_via_dns'),
@@ -582,8 +598,14 @@ def ParseCreateOptionsBase(
       ),
       network_tier=get_default('network_tier'),
       control_plane_egress_mode=get_default('control_plane_egress'),
+      enable_slice_controller=get_default('enable_slice_controller'),
+      autopilot_general_profile=get_default('autopilot_general_profile'),
+      node_architecture_taint_behavior=get_default(
+          'node_architecture_taint_behavior'
+      ),
   )
 
+
 GA = 'ga'
 BETA = 'beta'
 ALPHA = 'alpha'
@@ -674,6 +696,9 @@ flags_to_add = {
         'hpaprofile': flags.AddHPAProfilesFlag,
         'autoupgrade': AddEnableAutoUpgradeWithDefault,
         'autopilotworkloadpolicies': flags.AddAutopilotWorkloadPoliciesFlag,
+        'autopilotclusterpolicies': (
+            lambda p: flags.AddAutopilotClusterPoliciesFlag(p, hidden=True)
+        ),
         'authenticatorsecurity': flags.AddAuthenticatorSecurityGroupFlags,
         'args': _Args,
         'basicauth': flags.AddBasicAuthFlags,
@@ -722,6 +747,9 @@ flags_to_add = {
         'logging': flags.AddLoggingFlag,
         'machinetype': flags.AddMachineTypeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'maintenancedisruptionbudget': lambda p: (
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=True)
+        ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
         ),
@@ -743,6 +771,9 @@ flags_to_add = {
         'nodelabels': flags.AddNodeLabelsFlag,
         'nodelocations': flags.AddNodeLocationsFlag,
         'nodetaints': flags.AddNodeTaintsFlag,
+        'nodearchitecturetaintbehavior': (
+            flags.AddNodeArchitectureTaintBehaviorFlag
+        ),
         'nodeversion': flags.AddNodeVersionFlag,
         'notificationconfig': flags.AddNotificationConfigFlag,
         'num_nodes': flags.AddNumNodes,
@@ -838,6 +869,10 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
+        'disableMultiNicLustre': flags.AddDisableMultiNicLustreFlag,
+        'enableLustreMultiNic': lambda p: flags.AddEnableLustreMultiRailFlag(
+            p, hidden=True
+        ),
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
@@ -846,10 +881,12 @@ flags_to_add = {
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
         'enableKernelModuleSignatureEnforcement': (
-            lambda p: flags.AddEnableKernelModuleSignatureEnforcementFlag(
-                p, hidden=True
-            )
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
         ),
+        'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
+            p, hidden=True
+        ),
+        'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
     },
     BETA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -863,6 +900,9 @@ flags_to_add = {
         'authenticatorsecurity': flags.AddAuthenticatorSecurityGroupFlags,
         'autoupgrade': AddEnableAutoUpgradeWithDefault,
         'autopilotworkloadpolicies': flags.AddAutopilotWorkloadPoliciesFlag,
+        'autopilotclusterpolicies': (
+            lambda p: flags.AddAutopilotClusterPoliciesFlag(p, hidden=True)
+        ),
         'basicauth': flags.AddBasicAuthFlags,
         'binauthz': lambda p: flags.AddBinauthzFlags(
             p, release_track=base.ReleaseTrack.BETA
@@ -917,6 +957,9 @@ flags_to_add = {
         'legacyauth': flags.AddEnableLegacyAuthorizationFlag,
         'machinetype': flags.AddMachineTypeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'maintenancedisruptionbudget': lambda p: (
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=True)
+        ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
         ),
@@ -941,6 +984,9 @@ flags_to_add = {
         ),
         'networkpolicy': flags.AddNetworkPolicyFlags,
         'nodetaints': flags.AddNodeTaintsFlag,
+        'nodearchitecturetaintbehavior': (
+            flags.AddNodeArchitectureTaintBehaviorFlag
+        ),
         'nodeidentity': flags.AddClusterNodeIdentityFlags,
         'nodeversion': flags.AddNodeVersionFlag,
         'nodelabels': flags.AddNodeLabelsFlag,
@@ -1050,11 +1096,15 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
+        'disableMultiNicLustre': flags.AddDisableMultiNicLustreFlag,
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
         'controlPlaneEgress': flags.AddControlPlaneEgressFlag,
         'managedOTelScope': lambda p: flags.AddManagedOTelScopeFlags(
+            p, hidden=False
+        ),
+        'managedMLDiagnostics': lambda p: flags.AddManagedMLDiagnosticsFlags(
             p, hidden=True
         ),
         'autopilotPrivilegedAdmission': (
@@ -1062,10 +1112,15 @@ flags_to_add = {
         ),
         'podsnapshots': flags.AddPodSnapshotConfigFlags,
         'enableKernelModuleSignatureEnforcement': (
-            lambda p: flags.AddEnableKernelModuleSignatureEnforcementFlag(
-                p, hidden=True
-            )
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
         ),
+        'enableLustreMultiNic': lambda p: flags.AddEnableLustreMultiRailFlag(
+            p, hidden=True
+        ),
+        'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
+            p, hidden=True
+        ),
+        'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
     },
     ALPHA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -1078,6 +1133,9 @@ flags_to_add = {
         'autorepair': AddAutoRepair,
         'autoscalingprofiles': flags.AddAutoscalingProfilesFlag,
         'autopilotworkloadpolicies': flags.AddAutopilotWorkloadPoliciesFlag,
+        'autopilotclusterpolicies': (
+            lambda p: flags.AddAutopilotClusterPoliciesFlag(p, hidden=True)
+        ),
         'hpaprofile': flags.AddHPAProfilesFlag,
         'basicauth': flags.AddBasicAuthFlags,
         'cloudlogging': flags.AddEnableCloudLogging,
@@ -1145,6 +1203,9 @@ flags_to_add = {
         'maxnodes': flags.AddMaxNodesPerPool,
         'maxpodspernode': flags.AddMaxPodsPerNodeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'maintenancedisruptionbudget': lambda p: (
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=True)
+        ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
         ),
@@ -1160,6 +1221,9 @@ flags_to_add = {
         'monitoring': flags.AddMonitoringFlag,
         'networkpolicy': flags.AddNetworkPolicyFlags,
         'nodetaints': flags.AddNodeTaintsFlag,
+        'nodearchitecturetaintbehavior': (
+            flags.AddNodeArchitectureTaintBehaviorFlag
+        ),
         'nodeidentity': flags.AddClusterNodeIdentityFlags,
         'nodeversion': flags.AddNodeVersionFlag,
         'nodelabels': flags.AddNodeLabelsFlag,
@@ -1272,11 +1336,15 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
+        'disableMultiNicLustre': flags.AddDisableMultiNicLustreFlag,
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
         'controlPlaneEgress': flags.AddControlPlaneEgressFlag,
         'managedOTelScope': lambda p: flags.AddManagedOTelScopeFlags(
+            p, hidden=False
+        ),
+        'managedMLDiagnostics': lambda p: flags.AddManagedMLDiagnosticsFlags(
             p, hidden=True
         ),
         'autopilotPrivilegedAdmission': (
@@ -1284,10 +1352,15 @@ flags_to_add = {
         ),
         'podsnapshots': flags.AddPodSnapshotConfigFlags,
         'enableKernelModuleSignatureEnforcement': (
-            lambda p: flags.AddEnableKernelModuleSignatureEnforcementFlag(
-                p, hidden=True
-            )
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
         ),
+        'enableLustreMultiNic': lambda p: flags.AddEnableLustreMultiRailFlag(
+            p, hidden=True
+        ),
+        'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
+            p, hidden=True
+        ),
+        'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
     },
 }
 # LINT.ThenChange(create_auto.py:auto_flags)
@@ -1381,7 +1454,16 @@ class Create(base.CreateCommand):
           'https://cloud.google.com/kubernetes-engine/docs/how-to/private-clusters'
       )
 
-    if not options.enable_ip_alias and not options.enable_auto_ipam:
+    is_cluster_ipv6 = (
+        options.stack_type
+        and options.stack_type.lower() == api_constants.IPV6_STACK_TYPE
+    )
+
+    if (
+        not options.enable_ip_alias
+        and not options.enable_auto_ipam
+        and not is_cluster_ipv6
+    ):
       max_node_number = util.CalculateMaxNodeNumberByPodRange(
           options.cluster_ipv4_cidr
       )
@@ -1570,6 +1652,9 @@ class CreateBeta(Create):
         get_default('cross_connect_subnetworks'))
     ops.enable_service_externalips = get_default('enable_service_externalips')
     ops.enable_managed_prometheus = get_default('enable_managed_prometheus')
+    ops.enable_managed_mldiagnostics = get_default(
+        'enable_managed_mldiagnostics'
+    )
     ops.auto_monitoring_scope = get_default('auto_monitoring_scope')
     ops.spot = get_default('spot')
     ops.maintenance_interval = get_default('maintenance_interval')
@@ -1643,6 +1728,7 @@ class CreateBeta(Create):
     ops.enable_auto_ipam = get_default('enable_auto_ipam')
     ops.enable_k8s_tokens_via_dns = get_default('enable_k8s_tokens_via_dns')
     ops.enable_legacy_lustre_port = get_default('enable_legacy_lustre_port')
+    ops.disable_multi_nic_lustre = get_default('disable_multi_nic_lustre')
     ops.enable_default_compute_class = get_default(
         'enable_default_compute_class'
     )
@@ -1650,6 +1736,9 @@ class CreateBeta(Create):
     ops.control_plane_egress_mode = get_default('control_plane_egress')
     ops.gpudirect_strategy = get_default('gpudirect_strategy')
     ops.managed_otel_scope = get_default('managed_otel_scope')
+    ops.enable_managed_mldiagnostics = get_default(
+        'enable_managed_mldiagnostics'
+    )
     return ops
 
 
@@ -1736,6 +1825,9 @@ class CreateAlpha(Create):
         get_default('cross_connect_subnetworks'))
     ops.enable_service_externalips = get_default('enable_service_externalips')
     ops.enable_managed_prometheus = get_default('enable_managed_prometheus')
+    ops.enable_managed_mldiagnostics = get_default(
+        'enable_managed_mldiagnostics'
+    )
     ops.auto_monitoring_scope = get_default('auto_monitoring_scope')
     ops.spot = get_default('spot')
     ops.maintenance_interval = get_default('maintenance_interval')
@@ -1806,6 +1898,7 @@ class CreateAlpha(Create):
     ops.enable_auto_ipam = get_default('enable_auto_ipam')
     ops.enable_k8s_tokens_via_dns = get_default('enable_k8s_tokens_via_dns')
     ops.enable_legacy_lustre_port = get_default('enable_legacy_lustre_port')
+    ops.disable_multi_nic_lustre = get_default('disable_multi_nic_lustre')
     ops.enable_default_compute_class = get_default(
         'enable_default_compute_class'
     )
@@ -1813,4 +1906,5 @@ class CreateAlpha(Create):
     ops.control_plane_egress_mode = get_default('control_plane_egress')
     ops.gpudirect_strategy = get_default('gpudirect_strategy')
     ops.managed_otel_scope = get_default('managed_otel_scope')
+    ops.autopilot_general_profile = get_default('autopilot_general_profile')
     return ops
